#
# spec file for package gnuchess
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnuchess
Version:        6.2.1
Release:        8.1
Summary:        GNU Chess Program
License:        GPL-3.0+
Group:          Amusements/Games/Board/Chess
Url:            http://www.gnu.org/software/chess/
Source0:        http://ftp.gnu.org/gnu/chess/%{name}-%{version}.tar.gz
# WARNING: Don't forget to re-generate book.dat manually before submit!
# Simply remove the source and build, updated book will be generated.
Source1:        book_1.02.pgn.bz2
#Source2:        book.dat.bz2
Source3:        genbook.sh
Source5:        xgnuchess
Source6:        http://ftp.gnu.org/gnu/chess/%{name}-%{version}.tar.gz.sig
Source7:        http://savannah.gnu.org/project/memberlist-gpgkeys.php?group=chess&download=1#/gnuchess.keyring
Patch0:         CVE-2015-8972.patch
BuildRequires:  expect
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  readline-devel
Requires(post): info
Requires(preun): info
Recommends:     xboard
Provides:       chess_backend
Provides:       gchess
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A worthy chess opponent that runs in text mode. Find an X11 interface
in the xboard package.

%prep
%setup -q
%patch0 -p1

%build
%configure
make %{?_smp_mflags}
sed -i 's/^Book[[:space:]]*=[[:space:]]*false/Book = true/;s/^OwnBook[[:space:]]=[[:space:]]*false/OwnBook = true/' src/gnuchess.ini
sh %{SOURCE3} %{SOURCE1}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
# install xgnuchess
install -m 755 %{SOURCE5} %{buildroot}/%{_bindir}
%find_lang %{name}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun
if [ $1 = 0 ] ; then
  if [ -f %{_infodir}/%{name}.info.gz ] ; then
    %install_info --info-dir=%{_infodir} --delete %{_infodir}/%{name}.info.gz
  fi
fi

%files -f %{name}.lang
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README TODO
%{_bindir}/*
%{_mandir}/man*/*
%{_infodir}/gnuchess.info.gz
%{_datadir}/gnuchess
%dir %{_datadir}/games/plugins
%dir %{_datadir}/games/plugins/logos
%{_datadir}/games/plugins/logos/%{name}.png
%dir %{_datadir}/games/plugins/xboard
%{_datadir}/games/plugins/xboard/%{name}.eng

%changelog
* Tue Nov 15 2016 astieger@suse.com
- CVE-2015-8972: user input buffer overflow (boo#1010143),
  truncate user input if longer than 128 characters
  adding CVE-2015-8972.patch
* Sun Jan 18 2015 andreas.stieger@gmx.de
- gnuchess 6.2.1:
  - Man page in English.
- includes changes from 6.2.0;
  - "Tighter connection" with XBoard by means of an engine file and
    a logo, as expected by XBoard (>= 4.6.0).
  - Uppercase chars only for piece names, as Fruit doesn't like
  lowercase.
  - A man page based on help2man.
- verify source signature
* Sun Oct  5 2014 andreas.stieger@gmx.de
- gnuchess 6.1.2:
  * CFLAGS replaced by CPPFLAGS in info.
  * Fix for correct handling of castling moves.
  * Include translations to other languages.
- includes changes from 6.1.1:
  * Include translations to other languages.
  * Minor corrections in translatable strings.
  * Migrate frontend to C++.
  * Use autoconf 2.69 and require it in configure.ac.
  * Use automake 1.14.
- includes changes from 6.1.0:
  * Add support for package internationalization based on gettext
  * Include first translations provided by the Translation Team.
  * Graphic mode, a new board shape based on the unicode characters
    for chess.
  * pgnreplay command, similar to pgnload, with the capability of
    manually showing a saved game step by step and moving backwards
  * Fix bug in setboard.
  * Avoid using 100%% CPU in UCI mode.
  * Rename the small book.bin as smallbook.bin.
- includes changes from 6.0.3:
  * Update to autoconf 2.69, automake 1.13
  * If in manual mode, keep it after undo.
  * Remove some unused code.
  * Avoid crashing when importing book_1.01.pgn
- licence is GPL-3.0+
* Fri Oct 26 2012 lars@linux-schulserver.de
- update gnuchess to 6.0.2:
  + New option --addbook to compile a book.
  + Maximum file name length of EPD files extended to 127 characters.
  + Book file allowed to be read only unless the BookLearn
    option is set.
- new upstream Url
- removed upstreamed gnuchess-return-nonvoid.patch
- recommend xboard
* Tue Nov 29 2011 jreidinger@suse.com
- update gnuchess to official version 6.0.1
- clean up patches
- change generation of recent book dat from source during build
* Wed Aug  4 2010 packman@links2linux.de
- updated gnuchess to (unofficial) version 5.07.94.1b
- updated to most recent book.dat
- removed obsolete getline patch
- added patches to fix a few rpmlint-warnings/errors
- added gnuchess-add_new_bookpath.diff so gnuchess finds the default
  opening book in /usr/share/gnuchess
* Mon Jan 11 2010 packman@links2linux.de
- updated to (unofficial) version 5.07.9b by M. Vandenbergh
- added script "xgnuchess" to start xboard with gnuchess
  as first and second chess engine
- patches refreshed
- description updated
* Fri Oct 16 2009 marek.belisko@open-nandra.com
- Add missing fclose() and correct typo (bnc#534576)
* Sun Jun  7 2009 ro@suse.de
- rename getline to my_getline to avoid conflict with function
  from glibc
* Thu Nov  6 2008 ro@suse.de
- remove NoSource tag
* Fri Mar 30 2007 ro@suse.de
- added flex,bison to buildreq
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Apr  5 2005 mmj@suse.de
- Make gcc4 happy
* Thu Aug 26 2004 sbrabec@suse.cz
- Updated to version 5.07.
- Updated book to version 1.01.
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Thu Aug  7 2003 sbrabec@suse.cz
- Updated to version 5.06.
* Tue Feb 11 2003 sbrabec@suse.cz
- Updated to version 5.05.
- Adapt to new gnuchess packaging scheme.
- Added new build script genbook.sh to shrink source RPM.
* Tue Feb  4 2003 sbrabec@suse.cz
- Provide chess_backend.
* Mon Aug  6 2001 dan@suse.cz
- update to 5.02 version
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Tue May  2 2000 vinil@suse.cz
- prefix problem fixed
* Tue Apr 11 2000 vinil@suse.cz
- buildroot added
* Thu Jan 20 2000 ro@suse.de
- man to /usr/share/man
* Tue Oct 12 1999 ro@suse.de
- update to pl80
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
